/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalVar.h"
#include "HvControlSystem.h"
#include "HvControlIf.h"
#include "HvSignalLine.h"
#include "HvSignalBiquad.h"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvControlUnop.h"
#include "HvControlBinop.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_02yOqzfZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wmUCo5Xz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_toDdlFNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gk0xLpib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Hqn6b5UQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aDtasS2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iTuNFanq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3DwQ5nNr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BEVO6pxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Fu7zfhYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BGQq0ax9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NkZ9DeRy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ANYHxlaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_920wIWXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vwvCXF7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sEUgS6Bp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ejLVB9KF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K3rfGzrZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EaTo44kS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hJthWGDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WTMEwW08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lGIfmwVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hp064MSc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KuqVzjEx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jBtcYWmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3kuVtlCj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OtQdIPOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V6vMwxTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3Qdy6fmy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pqpbvynk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DGrDxDaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WcIdRQP3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vbIIBqnL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zGQ7BsKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a6VTX92I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g068qryB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UrTLOKUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KreI6omN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fr3i58n0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9DxD7WkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3WIVvxId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_91UAejxB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IoeESup8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Rb0wENdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iZot6OKB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2rJRUAHV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HWGMq5T7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5EmnoKao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ANLuXfLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hfLTk31D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3FbZRx1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j6VtDKRG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wGQAcYPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H5oQn1ep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wFJWBzAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AlixYGfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YF2HbcMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GOJxASWQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5fSEhnV6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g5EoozEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8piHw79w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vFxYwiMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OnafikVF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZuCxUfYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iJjf76LX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8th9jyyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_uZGxHpg7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TdRoSCVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jnsjpcSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1o9aKCfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ru1dNYbC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UbfroCP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EjlOIZ0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gRmRtMrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vDaXszPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pv9lL3LF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r9oK3cqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XE1ePSCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sGVzROQ3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yR2NnsAx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4PVS3BTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WGuSx7ym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VHxPMqwr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3ZfvpVkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_36QsZEDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HmccUU2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_iofZ4lfN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7B1n4s5Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cQPDVtJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CecrlNsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XtPvNuO4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sDf8K7nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fLI5O37S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_39uHujma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x1MjzLh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IXH89bAK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mJudu3Rf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AQeeXVs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PIZ0rDtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U3jWoSEL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TL52awyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Q790WmDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PMiyRORP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vvbmrzf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZTyP9Xwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yRQdba44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZmBvsg8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hlPS0z69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9Az0UnRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UO0rN7VF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_leFBKEFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ns8a7uGi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1tOMDqGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zbl4GM27_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tv6lHtJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oeRTQSQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ofUfiopN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WgMNMRyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RTd9VokE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jPyTQ1En_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wULIZXjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sPsLlFgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_knsK2bzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YWPPXWpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C9xaVcAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uU3X9ApG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LvOB0Je9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PYykHCpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UGHerblH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_flhfgjHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cHjCJYXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZA2hg7PW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mUG5Sb7I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UZqu7wII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jGmkDZX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Z61eJBWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WXjprgUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lsyLn6ph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4VpGgw6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_woKhAn7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_piw2UGzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l9jKwLeQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mbY4aHJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i14YCv8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KDQG3MAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nrjpLMv6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mwhQ6PpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qek9DUzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_029iLOlT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m4azxfwf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SBFCuFwi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bpxfQEKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_30zXKLMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sj2nDP8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bnkuYOWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BuLH5I54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pO4y0kL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iHmpeNoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OEH7KNt1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WyeWlkoJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DiLs2AHt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dSaEuxRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vm9a940j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8lTm10O4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vKD05RPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KtMXdYx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C8xbtcPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y8R4RGmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AgA8bEvx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PtQKQv7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o0QRHLgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8UoX2WIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rUtFhAQd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6nNla3C4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D3kwRozq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9rqvbLZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JzcNsurN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E7w2xrx9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_crlgGohU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8XZtanVl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RBuS6d0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JsCrNgyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_t1tzzApu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BkMK5Mdh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0yAVWn65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YmVRfIU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RaCTPgUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_loHeiGnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MO88P6tt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N8jKWHDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mdtk8ozj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R6W87BP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rxj0OqEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GD2pieez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r6M9rX3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eGS1WuDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qEJ5rGHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1XUMJqf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l5w3LPjE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eNLl2jbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8u2YP4IC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5ItndEyT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vjvu88QG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ypj81eQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5KeXSXVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jay0jkmK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JPcfbZIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_agp6q5Kz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ylvm1fNr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3tx8unAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q64bnUv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CxnVZy9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_txguN54Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DiBSwOzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_a8lYA8q4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0i4Rmrtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kzZYXbLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JO2Ju7br_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_znEYnf2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JpLzFobA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fzng4cZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GlUJ7M7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iCaNVtJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ifmmi35o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2yBUsvrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fya83aMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dx6F1q49_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ReNDCDxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KXXLVJSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_airvZjcm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wwsqxTU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_foSfZXwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7AbWB6rR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0GYPE71e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CKrIIoSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WYQlLuYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E6RImBtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xBOm4oIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mJH5EMZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_b0gXFTns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6DRDYdzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bb7sQmon_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CCV85RQ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6eBex9he_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R0MwD3vm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hrI3BGXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7RiDy1qB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WWscL0Ip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_equbDlXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bSRXDdBT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B0ZjljPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ll36eLop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4oZo70op_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fx7efuAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xb5HvaSs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Oty3M6DA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q8yn2gVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TsQRAg3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_asZskuSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_srA7msMe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uhQDBNKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wlXIdniC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gemrg2wO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SmpqQ0en_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ou8KCfB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DhylDHET_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ZXkAK71i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5MKM0a5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qtPe0qo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_comcRrAl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vmM2heQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pfkDyPE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cMtm8Hzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IRJ4E0rN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YhKLVnqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9dYfkBl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tF6s5hUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JmpxYC5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_goIKTT4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jeyMmwSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AX4KfXDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aWoLdBzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rg5q3Ah4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7X8b3aYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_elJB6Ko9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ia9niJB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QquBMlKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HMSCp0Zj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XfbkHzCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p2s1frOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sJ1t7MHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fB1sfUBj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_avf0XxJ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_n93tcvaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ge0dFVsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sA52qDho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zzm2PRXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lIyxEKVc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6034uUDA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VpDvQpLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5fC0KrN1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJz6hTrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zv4QAmpc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BJFQiZnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2BKnqPgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qknS8joS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oxk21nYu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GUNkatqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AUkfpzY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_egLrQLDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Z1tQrQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QyalaIuR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EkypPMIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CquFMYsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i0btevds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hekzcKjx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MsOeSNqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3tb23vXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8h9GfvJ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n6LSvECA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hZY4Ta09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_plnHedhZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7MCvkHxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1oXe4AsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dpIA2ZJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RGFfgNFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WaWyiGlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_skmGSQru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RlSG1E75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SbiQsRXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N22cNWRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F01UgdMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R9xz2dMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LMHAuT93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F7wQnwMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u5PuxIRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7NqhP8in_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MoV0uXKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zGijTCCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_L1ZuQQmU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_h9IYuzk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AheKeFYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7up04AB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dZF9FcxI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4759crkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_s9d2vEuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_78ifDoDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mfrD6RCA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5kjlk7o4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Y7yjjJkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Po4DXgax_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zUnJSkNS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SxwGkO1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pjiG5RTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PLgyY2Aq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xSifbAxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LgZsfDmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Eg01vSzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9JDHiXU0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XwRYyjJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cwgq3Sqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3VATH7za_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YZG2thHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RrB4OIO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I0SNdJq8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2q0na0q4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3zjwqAai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Iv7AxItB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Lq1RGwey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rouQBedI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dZzIMWqj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k8ZvXwhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wZNlToA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gBrptIZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AW1GqSeW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lpYrYbFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_heRbGOqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nYBJv0Ev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xj7hJBWj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CnYCUFR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PeLfCAQa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BFU3u1UU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sePc7Jxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TQwU5ChU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LPEztlW7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_APWzh9t5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1zBIllp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LU7VC8nU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DhaP7mS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fpwtGzrD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_PScbg5LC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oaNu8jfi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lF7oNC5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HHQacoKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dg4kzjbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IFX1tqJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rj1xdA0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3269fL5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GjJ0r60q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_87ywMf0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aT0JY6Ja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8sCaTw68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VG9VxOld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ro252ND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ql8YRpWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sQG1mT7A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5HsD8gKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qYKqWM29_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Sw9Y2rmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lsQOppJg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T6JvZQeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yl9TemmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j6w1nTa8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eDu2MLJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j4RKFzhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lh5xm1ph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ml1bZf75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xeMz4pTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KHxFjEs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LhpxI8ep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sBNC8hHH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cvELjW5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yKhxArxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uN6XpXPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FQ902nOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ugjFLexI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_e9PD7827_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vo7Rc5VV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mtvPk7uR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mrIh1TF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vMdmVZW1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5XDVVVDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mL6Zf8qB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OAjhIxW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HyI8K1CZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oDfYM81Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_N9YpxU0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_djKBC6JK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3P4SkBY5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fAMaxuXV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RfTOPj0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BjswQNZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_spGR8xnW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eHCWdZbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xYXqADUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sq8wA51T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Whuem0Ed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SyvuRd7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g2SiRrCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OG0arSLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KeBAMgUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ciTtFNrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jSa4hwgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9iWOp4Fz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jIdnnhtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ht6MQQ5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WfHbWh1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XZOyPnMU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PvMr3x8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YOYT3PIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kkOfwff1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hLH46eJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4HL5yKhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_12hnLdyN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eWqd1nAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I7eRl4B9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y8iQG4Re_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HIKJNP3b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_I3p9EB0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_uPEDRmUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BH9ayprz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZSa70OrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FsDIBMzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4D3Mwbl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VcfwnpGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kmkEDO1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_61hanb3C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ae2FmY5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xUKHXuvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yhqoxek6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AxGe6ANX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3wsGY1ay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jDHrGKQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oKGzb0QI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7g63B0zg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IK4cqkFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KRfUd7s7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yZeDFrDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nbh6accg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PYQgnU6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VroHJn9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K0cMuyaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kHHKfZ8U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lEa9gR5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7Gvn4gtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_moK361Rm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ozFqli2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ofTTzdLl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_htjAVaB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yjKuBbhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_BizayESp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_baWdpGie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZXnBZ4m8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_goznqwoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ppXwroSp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hhDh9WaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jbvsokzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m47vjHWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KLCPvqpG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UGxKJTYg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Tpy8W2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WdwjZMSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4Dmb6T3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W6Q4QMZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yPcHyWXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QcLppjLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U3JBH6Xi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L5ZjACJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hni4AJqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FCefK6Yw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A8UB2XmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mBJ05FaO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Cl6r5xk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A9nc2XzR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7FKoyRzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hZP4T9bG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T6Db65q5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zmaNsDUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BGlaUaNa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_RsNiEM7i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YHidIriA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gtm6mZnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gTYTs4GS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dt57KuIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1DsgQFbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LSuKXpI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_twCapvQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IXENdNXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kP6AricI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l84zJ6Rk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tULBQV4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H5FUv6DF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mtM7CiYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EIqwyNFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K11AjaxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qx6Y3RnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Bc7kwpR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fMWA4luM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_58Og4Kz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_83kvNcw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JLs2VTPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Sdz2Xz9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oAI3tNIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BfX6RUF1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pHbslfds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DjWuJ9v3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_x3AnOB1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RSsZJHsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UCXYKKRR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QJ3ODicB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KPYHoIA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qKzCZVY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NSUFcuUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IzwsZcT1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rgcueciq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_onJX4uWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UF8lRJIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vNWtHFb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_07wPQ7wL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AgOfE25K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Mn493D4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tzgjcIRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CNW6yD5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YXIRdNOt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2SG4zOYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QWBym4OG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dAAftDKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1og6r1oc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CFeFj9i5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_10mjWh6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4SNfmUE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_bgQWnU7N;
  SignalLine sLine_HCWUa98w;
  SignalLine sLine_l0MBLnDE;
  SignalLine sLine_lrNSe0OV;
  SignalLine sLine_AWvzdjR1;
  SignalBiquad sBiquad_s_NMGwHMRJ;
  SignalLine sLine_ns43tG3A;
  SignalLine sLine_u8c9p1Ok;
  SignalLine sLine_lCedbyet;
  SignalLine sLine_vbekwRdh;
  SignalBiquad sBiquad_s_BLD12yEt;
  SignalLine sLine_YxPaf8zY;
  SignalLine sLine_VJu9PwHw;
  SignalLine sLine_8CKgqe7i;
  SignalLine sLine_9jFPIohT;
  SignalLine sLine_eCJuFOfQ;
  SignalBiquad sBiquad_s_TZJj3E9k;
  SignalLine sLine_xxhJ8OVA;
  SignalLine sLine_RPwjOfxb;
  SignalLine sLine_tVQPJplh;
  SignalLine sLine_og5utLJ3;
  SignalLine sLine_bIQsSsRK;
  SignalBiquad sBiquad_s_0jwAvb7b;
  SignalLine sLine_6LoJHWS1;
  SignalLine sLine_tnGau76Y;
  SignalLine sLine_fWP3lcY4;
  SignalLine sLine_FewIlr4C;
  SignalBiquad sBiquad_s_6qMngM2P;
  SignalLine sLine_gQb3FBJB;
  SignalLine sLine_lIokGcfM;
  SignalLine sLine_PUG2Vmnt;
  SignalLine sLine_B9hRspnQ;
  SignalLine sLine_MiJ0wviz;
  SignalBiquad sBiquad_s_Vnc04Drh;
  ControlVar cVar_02yOqzfZ;
  ControlVar cVar_wmUCo5Xz;
  ControlVar cVar_toDdlFNp;
  ControlVar cVar_gk0xLpib;
  ControlSlice cSlice_aDtasS2x;
  ControlVar cVar_iTuNFanq;
  ControlVar cVar_BEVO6pxK;
  ControlIf cIf_Fu7zfhYD;
  ControlIf cIf_BGQq0ax9;
  ControlBinop cBinop_ANYHxlaF;
  ControlBinop cBinop_920wIWXu;
  ControlBinop cBinop_ejLVB9KF;
  ControlBinop cBinop_K3rfGzrZ;
  ControlBinop cBinop_hJthWGDR;
  ControlIf cIf_WTMEwW08;
  ControlBinop cBinop_lGIfmwVV;
  ControlBinop cBinop_Hp064MSc;
  ControlBinop cBinop_jBtcYWmw;
  ControlBinop cBinop_3kuVtlCj;
  ControlBinop cBinop_OtQdIPOk;
  ControlVar cVar_WcIdRQP3;
  ControlIf cIf_vbIIBqnL;
  ControlIf cIf_zGQ7BsKr;
  ControlBinop cBinop_g068qryB;
  ControlBinop cBinop_UrTLOKUJ;
  ControlBinop cBinop_9DxD7WkT;
  ControlBinop cBinop_3WIVvxId;
  ControlBinop cBinop_IoeESup8;
  ControlIf cIf_Rb0wENdK;
  ControlBinop cBinop_iZot6OKB;
  ControlBinop cBinop_2rJRUAHV;
  ControlBinop cBinop_5EmnoKao;
  ControlBinop cBinop_ANLuXfLA;
  ControlBinop cBinop_hfLTk31D;
  ControlVar cVar_wFJWBzAw;
  ControlIf cIf_AlixYGfP;
  ControlIf cIf_YF2HbcMT;
  ControlBinop cBinop_5fSEhnV6;
  ControlBinop cBinop_g5EoozEJ;
  ControlBinop cBinop_OnafikVF;
  ControlBinop cBinop_ZuCxUfYP;
  ControlBinop cBinop_8th9jyyC;
  ControlIf cIf_uZGxHpg7;
  ControlBinop cBinop_TdRoSCVK;
  ControlBinop cBinop_jnsjpcSF;
  ControlBinop cBinop_ru1dNYbC;
  ControlBinop cBinop_UbfroCP4;
  ControlBinop cBinop_EjlOIZ0Z;
  ControlIf cIf_XE1ePSCd;
  ControlSlice cSlice_yR2NnsAx;
  ControlVar cVar_4PVS3BTw;
  ControlSlice cSlice_3ZfvpVkV;
  ControlVar cVar_36QsZEDv;
  ControlSlice cSlice_7B1n4s5Q;
  ControlVar cVar_cQPDVtJ0;
  ControlSlice cSlice_sDf8K7nR;
  ControlVar cVar_fLI5O37S;
  ControlBinop cBinop_vvbmrzf5;
  ControlBinop cBinop_yRQdba44;
  ControlBinop cBinop_ZmBvsg8F;
  ControlBinop cBinop_UO0rN7VF;
  ControlBinop cBinop_leFBKEFc;
  ControlBinop cBinop_Ns8a7uGi;
  ControlBinop cBinop_1tOMDqGn;
  ControlBinop cBinop_Zbl4GM27;
  ControlVar cVar_Tv6lHtJj;
  ControlBinop cBinop_oeRTQSQS;
  ControlBinop cBinop_ofUfiopN;
  ControlBinop cBinop_WgMNMRyF;
  ControlBinop cBinop_RTd9VokE;
  ControlBinop cBinop_jPyTQ1En;
  ControlBinop cBinop_wULIZXjC;
  ControlBinop cBinop_sPsLlFgM;
  ControlBinop cBinop_YWPPXWpd;
  ControlVar cVar_C9xaVcAd;
  ControlVar cVar_uU3X9ApG;
  ControlBinop cBinop_mUG5Sb7I;
  ControlBinop cBinop_UZqu7wII;
  ControlBinop cBinop_jGmkDZX4;
  ControlBinop cBinop_WXjprgUu;
  ControlBinop cBinop_lsyLn6ph;
  ControlBinop cBinop_4VpGgw6d;
  ControlBinop cBinop_woKhAn7E;
  ControlBinop cBinop_piw2UGzD;
  ControlBinop cBinop_l9jKwLeQ;
  ControlBinop cBinop_DiLs2AHt;
  ControlBinop cBinop_vm9a940j;
  ControlBinop cBinop_8lTm10O4;
  ControlBinop cBinop_C8xbtcPV;
  ControlBinop cBinop_y8R4RGmX;
  ControlBinop cBinop_AgA8bEvx;
  ControlBinop cBinop_PtQKQv7E;
  ControlBinop cBinop_o0QRHLgp;
  ControlBinop cBinop_8UoX2WIv;
  ControlBinop cBinop_rUtFhAQd;
  ControlBinop cBinop_D3kwRozq;
  ControlVar cVar_9rqvbLZj;
  ControlVar cVar_JzcNsurN;
  ControlVar cVar_E7w2xrx9;
  ControlBinop cBinop_0yAVWn65;
  ControlBinop cBinop_YmVRfIU2;
  ControlBinop cBinop_RaCTPgUR;
  ControlBinop cBinop_MO88P6tt;
  ControlBinop cBinop_N8jKWHDz;
  ControlBinop cBinop_mdtk8ozj;
  ControlBinop cBinop_R6W87BP5;
  ControlBinop cBinop_Rxj0OqEH;
  ControlBinop cBinop_Q64bnUv0;
  ControlBinop cBinop_txguN54Z;
  ControlBinop cBinop_DiBSwOzj;
  ControlBinop cBinop_kzZYXbLl;
  ControlBinop cBinop_JO2Ju7br;
  ControlBinop cBinop_znEYnf2Q;
  ControlBinop cBinop_JpLzFobA;
  ControlBinop cBinop_Fzng4cZA;
  ControlBinop cBinop_iCaNVtJH;
  ControlBinop cBinop_2yBUsvrN;
  ControlBinop cBinop_Fya83aMo;
  ControlBinop cBinop_ReNDCDxN;
  ControlBinop cBinop_KXXLVJSe;
  ControlBinop cBinop_airvZjcm;
  ControlBinop cBinop_foSfZXwY;
  ControlVar cVar_7AbWB6rR;
  ControlVar cVar_0GYPE71e;
  ControlVar cVar_CKrIIoSf;
  ControlBinop cBinop_Bb7sQmon;
  ControlBinop cBinop_CCV85RQ4;
  ControlBinop cBinop_6eBex9he;
  ControlBinop cBinop_hrI3BGXp;
  ControlBinop cBinop_7RiDy1qB;
  ControlBinop cBinop_WWscL0Ip;
  ControlBinop cBinop_equbDlXO;
  ControlBinop cBinop_bSRXDdBT;
  ControlBinop cBinop_B0ZjljPU;
  ControlBinop cBinop_wlXIdniC;
  ControlBinop cBinop_SmpqQ0en;
  ControlBinop cBinop_Ou8KCfB1;
  SignalVarf sVarf_sKdQ3K0V;
  SignalVarf sVarf_IYWmfA2F;
  SignalVarf sVarf_BfTdSstz;
  ControlSlice cSlice_ZXkAK71i;
  ControlVar cVar_5MKM0a5E;
  ControlVar cVar_comcRrAl;
  ControlIf cIf_vmM2heQ8;
  ControlIf cIf_pfkDyPE6;
  ControlBinop cBinop_IRJ4E0rN;
  ControlBinop cBinop_YhKLVnqg;
  ControlBinop cBinop_JmpxYC5x;
  ControlBinop cBinop_goIKTT4U;
  ControlBinop cBinop_AX4KfXDb;
  ControlIf cIf_aWoLdBzS;
  ControlBinop cBinop_rg5q3Ah4;
  ControlBinop cBinop_7X8b3aYY;
  ControlBinop cBinop_ia9niJB3;
  ControlBinop cBinop_QquBMlKy;
  ControlBinop cBinop_HMSCp0Zj;
  ControlVar cVar_avf0XxJ2;
  ControlIf cIf_n93tcvaC;
  ControlIf cIf_Ge0dFVsP;
  ControlBinop cBinop_zzm2PRXm;
  ControlBinop cBinop_lIyxEKVc;
  ControlBinop cBinop_5fC0KrN1;
  ControlBinop cBinop_ZJz6hTrI;
  ControlBinop cBinop_BJFQiZnD;
  ControlIf cIf_2BKnqPgY;
  ControlBinop cBinop_qknS8joS;
  ControlBinop cBinop_Oxk21nYu;
  ControlBinop cBinop_AUkfpzY8;
  ControlBinop cBinop_egLrQLDO;
  ControlBinop cBinop_7Z1tQrQK;
  ControlVar cVar_hekzcKjx;
  ControlIf cIf_MsOeSNqr;
  ControlIf cIf_3tb23vXG;
  ControlBinop cBinop_n6LSvECA;
  ControlBinop cBinop_hZY4Ta09;
  ControlBinop cBinop_1oXe4AsE;
  ControlBinop cBinop_dpIA2ZJM;
  ControlBinop cBinop_WaWyiGlE;
  ControlIf cIf_skmGSQru;
  ControlBinop cBinop_RlSG1E75;
  ControlBinop cBinop_SbiQsRXN;
  ControlBinop cBinop_F01UgdMa;
  ControlBinop cBinop_R9xz2dMs;
  ControlBinop cBinop_LMHAuT93;
  ControlIf cIf_zGijTCCs;
  ControlSlice cSlice_h9IYuzk1;
  ControlVar cVar_AheKeFYL;
  ControlSlice cSlice_4759crkE;
  ControlVar cVar_s9d2vEuL;
  ControlSlice cSlice_5kjlk7o4;
  ControlVar cVar_Y7yjjJkD;
  ControlSlice cSlice_SxwGkO1u;
  ControlVar cVar_pjiG5RTU;
  ControlBinop cBinop_I0SNdJq8;
  ControlBinop cBinop_3zjwqAai;
  ControlBinop cBinop_Iv7AxItB;
  ControlBinop cBinop_dZzIMWqj;
  ControlBinop cBinop_k8ZvXwhn;
  ControlBinop cBinop_wZNlToA0;
  ControlBinop cBinop_gBrptIZH;
  ControlBinop cBinop_AW1GqSeW;
  ControlVar cVar_lpYrYbFQ;
  ControlBinop cBinop_heRbGOqZ;
  ControlBinop cBinop_nYBJv0Ev;
  ControlBinop cBinop_xj7hJBWj;
  ControlBinop cBinop_CnYCUFR1;
  ControlBinop cBinop_PeLfCAQa;
  ControlBinop cBinop_BFU3u1UU;
  ControlBinop cBinop_sePc7Jxr;
  ControlBinop cBinop_LPEztlW7;
  ControlVar cVar_APWzh9t5;
  ControlVar cVar_1zBIllp5;
  ControlBinop cBinop_HHQacoKx;
  ControlBinop cBinop_Dg4kzjbQ;
  ControlBinop cBinop_IFX1tqJX;
  ControlBinop cBinop_3269fL5M;
  ControlBinop cBinop_GjJ0r60q;
  ControlBinop cBinop_87ywMf0h;
  ControlBinop cBinop_aT0JY6Ja;
  ControlBinop cBinop_8sCaTw68;
  ControlBinop cBinop_VG9VxOld;
  ControlBinop cBinop_cvELjW5M;
  ControlBinop cBinop_uN6XpXPf;
  ControlBinop cBinop_FQ902nOt;
  ControlBinop cBinop_vo7Rc5VV;
  ControlBinop cBinop_mtvPk7uR;
  ControlBinop cBinop_mrIh1TF5;
  ControlBinop cBinop_vMdmVZW1;
  ControlBinop cBinop_5XDVVVDo;
  ControlBinop cBinop_mL6Zf8qB;
  ControlBinop cBinop_OAjhIxW3;
  ControlBinop cBinop_oDfYM81Y;
  ControlVar cVar_N9YpxU0c;
  ControlVar cVar_djKBC6JK;
  ControlVar cVar_3P4SkBY5;
  ControlBinop cBinop_sq8wA51T;
  ControlBinop cBinop_Whuem0Ed;
  ControlBinop cBinop_SyvuRd7L;
  ControlBinop cBinop_OG0arSLq;
  ControlBinop cBinop_KeBAMgUI;
  ControlBinop cBinop_ciTtFNrB;
  ControlBinop cBinop_jSa4hwgY;
  ControlBinop cBinop_9iWOp4Fz;
  ControlBinop cBinop_ZSa70OrG;
  ControlBinop cBinop_4D3Mwbl3;
  ControlBinop cBinop_VcfwnpGc;
  ControlBinop cBinop_ae2FmY5w;
  ControlBinop cBinop_xUKHXuvY;
  ControlBinop cBinop_Yhqoxek6;
  ControlBinop cBinop_AxGe6ANX;
  ControlBinop cBinop_3wsGY1ay;
  ControlBinop cBinop_oKGzb0QI;
  ControlBinop cBinop_IK4cqkFd;
  ControlBinop cBinop_KRfUd7s7;
  ControlBinop cBinop_nbh6accg;
  ControlBinop cBinop_PYQgnU6J;
  ControlBinop cBinop_VroHJn9Z;
  ControlBinop cBinop_kHHKfZ8U;
  ControlVar cVar_lEa9gR5M;
  ControlVar cVar_7Gvn4gtE;
  ControlVar cVar_moK361Rm;
  ControlBinop cBinop_ZXnBZ4m8;
  ControlBinop cBinop_goznqwoo;
  ControlBinop cBinop_ppXwroSp;
  ControlBinop cBinop_jbvsokzO;
  ControlBinop cBinop_m47vjHWS;
  ControlBinop cBinop_KLCPvqpG;
  ControlBinop cBinop_UGxKJTYg;
  ControlBinop cBinop_8Tpy8W2b;
  ControlBinop cBinop_WdwjZMSn;
  ControlBinop cBinop_6Cl6r5xk;
  ControlBinop cBinop_7FKoyRzD;
  ControlBinop cBinop_hZP4T9bG;
  SignalVarf sVarf_lPEpZ1nw;
  SignalVarf sVarf_HVeF34tA;
  SignalVarf sVarf_OF1jVdD3;
  SignalVarf sVarf_nJwofBSB;
  SignalVarf sVarf_10wfDD44;
  SignalVarf sVarf_4GWYbkzU;
  SignalVarf sVarf_iT6KFlKW;
  SignalVarf sVarf_IspF2ZOk;
  SignalVarf sVarf_W4p17SSJ;
  ControlVar cVar_T6Db65q5;
  ControlVar cVar_zmaNsDUf;
  ControlBinop cBinop_dt57KuIY;
  ControlBinop cBinop_1DsgQFbD;
  ControlBinop cBinop_LSuKXpI1;
  ControlBinop cBinop_IXENdNXy;
  ControlBinop cBinop_kP6AricI;
  ControlBinop cBinop_l84zJ6Rk;
  ControlBinop cBinop_tULBQV4D;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
