/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_bgQWnU7N);
  numBytes += sLine_init(&sLine_HCWUa98w);
  numBytes += sLine_init(&sLine_l0MBLnDE);
  numBytes += sLine_init(&sLine_lrNSe0OV);
  numBytes += sLine_init(&sLine_AWvzdjR1);
  numBytes += sBiquad_init(&sBiquad_s_NMGwHMRJ);
  numBytes += sLine_init(&sLine_ns43tG3A);
  numBytes += sLine_init(&sLine_u8c9p1Ok);
  numBytes += sLine_init(&sLine_lCedbyet);
  numBytes += sLine_init(&sLine_vbekwRdh);
  numBytes += sBiquad_init(&sBiquad_s_BLD12yEt);
  numBytes += sLine_init(&sLine_YxPaf8zY);
  numBytes += sLine_init(&sLine_VJu9PwHw);
  numBytes += sLine_init(&sLine_8CKgqe7i);
  numBytes += sLine_init(&sLine_9jFPIohT);
  numBytes += sLine_init(&sLine_eCJuFOfQ);
  numBytes += sBiquad_init(&sBiquad_s_TZJj3E9k);
  numBytes += sLine_init(&sLine_xxhJ8OVA);
  numBytes += sLine_init(&sLine_RPwjOfxb);
  numBytes += sLine_init(&sLine_tVQPJplh);
  numBytes += sLine_init(&sLine_og5utLJ3);
  numBytes += sLine_init(&sLine_bIQsSsRK);
  numBytes += sBiquad_init(&sBiquad_s_0jwAvb7b);
  numBytes += sLine_init(&sLine_6LoJHWS1);
  numBytes += sLine_init(&sLine_tnGau76Y);
  numBytes += sLine_init(&sLine_fWP3lcY4);
  numBytes += sLine_init(&sLine_FewIlr4C);
  numBytes += sBiquad_init(&sBiquad_s_6qMngM2P);
  numBytes += sLine_init(&sLine_gQb3FBJB);
  numBytes += sLine_init(&sLine_lIokGcfM);
  numBytes += sLine_init(&sLine_PUG2Vmnt);
  numBytes += sLine_init(&sLine_B9hRspnQ);
  numBytes += sLine_init(&sLine_MiJ0wviz);
  numBytes += sBiquad_init(&sBiquad_s_Vnc04Drh);
  numBytes += cVar_init_f(&cVar_02yOqzfZ, 0.0f);
  numBytes += cVar_init_f(&cVar_wmUCo5Xz, 0.0f);
  numBytes += cVar_init_f(&cVar_toDdlFNp, 0.0f);
  numBytes += cVar_init_f(&cVar_gk0xLpib, 0.0f);
  numBytes += cSlice_init(&cSlice_aDtasS2x, 1, -1);
  numBytes += cVar_init_f(&cVar_iTuNFanq, 1337.0f);
  numBytes += cVar_init_f(&cVar_BEVO6pxK, 0.0f);
  numBytes += cIf_init(&cIf_Fu7zfhYD, false);
  numBytes += cIf_init(&cIf_BGQq0ax9, false);
  numBytes += cBinop_init(&cBinop_ANYHxlaF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WTMEwW08, false);
  numBytes += cBinop_init(&cBinop_jBtcYWmw, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_3kuVtlCj, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_OtQdIPOk, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_WcIdRQP3, 0.0f);
  numBytes += cIf_init(&cIf_vbIIBqnL, false);
  numBytes += cIf_init(&cIf_zGQ7BsKr, false);
  numBytes += cBinop_init(&cBinop_g068qryB, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Rb0wENdK, false);
  numBytes += cBinop_init(&cBinop_5EmnoKao, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ANLuXfLA, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_hfLTk31D, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_wFJWBzAw, 0.0f);
  numBytes += cIf_init(&cIf_AlixYGfP, false);
  numBytes += cIf_init(&cIf_YF2HbcMT, false);
  numBytes += cBinop_init(&cBinop_5fSEhnV6, 0.0f); // __pow
  numBytes += cIf_init(&cIf_uZGxHpg7, false);
  numBytes += cBinop_init(&cBinop_ru1dNYbC, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_UbfroCP4, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EjlOIZ0Z, -15.0f); // __eq
  numBytes += cIf_init(&cIf_XE1ePSCd, false);
  numBytes += cSlice_init(&cSlice_yR2NnsAx, 1, -1);
  numBytes += cVar_init_f(&cVar_4PVS3BTw, 0.0f);
  numBytes += cSlice_init(&cSlice_3ZfvpVkV, 1, -1);
  numBytes += cVar_init_f(&cVar_36QsZEDv, 0.0f);
  numBytes += cSlice_init(&cSlice_7B1n4s5Q, 1, -1);
  numBytes += cVar_init_f(&cVar_cQPDVtJ0, 0.0f);
  numBytes += cSlice_init(&cSlice_sDf8K7nR, 1, -1);
  numBytes += cVar_init_f(&cVar_fLI5O37S, 0.313f);
  numBytes += cBinop_init(&cBinop_yRQdba44, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ZmBvsg8F, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Tv6lHtJj, 0.0f);
  numBytes += cVar_init_f(&cVar_C9xaVcAd, 1337.0f);
  numBytes += cVar_init_f(&cVar_uU3X9ApG, 0.3f);
  numBytes += cBinop_init(&cBinop_UZqu7wII, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lsyLn6ph, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4VpGgw6d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_woKhAn7E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_piw2UGzD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_l9jKwLeQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vm9a940j, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_8lTm10O4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_9rqvbLZj, 0.0f);
  numBytes += cVar_init_f(&cVar_JzcNsurN, 1337.0f);
  numBytes += cVar_init_f(&cVar_E7w2xrx9, 0.313f);
  numBytes += cBinop_init(&cBinop_YmVRfIU2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N8jKWHDz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mdtk8ozj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_R6W87BP5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Rxj0OqEH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_txguN54Z, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_DiBSwOzj, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7AbWB6rR, 0.0f);
  numBytes += cVar_init_f(&cVar_0GYPE71e, 1037.0f);
  numBytes += cVar_init_f(&cVar_CKrIIoSf, 0.4f);
  numBytes += cBinop_init(&cBinop_CCV85RQ4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7RiDy1qB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WWscL0Ip, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_equbDlXO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bSRXDdBT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_B0ZjljPU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_sKdQ3K0V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IYWmfA2F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BfTdSstz, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ZXkAK71i, 1, -1);
  numBytes += cVar_init_f(&cVar_5MKM0a5E, 1337.0f);
  numBytes += cVar_init_f(&cVar_comcRrAl, 0.0f);
  numBytes += cIf_init(&cIf_vmM2heQ8, false);
  numBytes += cIf_init(&cIf_pfkDyPE6, false);
  numBytes += cBinop_init(&cBinop_IRJ4E0rN, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aWoLdBzS, false);
  numBytes += cBinop_init(&cBinop_ia9niJB3, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_QquBMlKy, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_HMSCp0Zj, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_avf0XxJ2, 0.0f);
  numBytes += cIf_init(&cIf_n93tcvaC, false);
  numBytes += cIf_init(&cIf_Ge0dFVsP, false);
  numBytes += cBinop_init(&cBinop_zzm2PRXm, 0.0f); // __pow
  numBytes += cIf_init(&cIf_2BKnqPgY, false);
  numBytes += cBinop_init(&cBinop_AUkfpzY8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_egLrQLDO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7Z1tQrQK, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hekzcKjx, 0.0f);
  numBytes += cIf_init(&cIf_MsOeSNqr, false);
  numBytes += cIf_init(&cIf_3tb23vXG, false);
  numBytes += cBinop_init(&cBinop_n6LSvECA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_skmGSQru, false);
  numBytes += cBinop_init(&cBinop_F01UgdMa, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_R9xz2dMs, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_LMHAuT93, -15.0f); // __eq
  numBytes += cIf_init(&cIf_zGijTCCs, false);
  numBytes += cSlice_init(&cSlice_h9IYuzk1, 1, -1);
  numBytes += cVar_init_f(&cVar_AheKeFYL, 0.0f);
  numBytes += cSlice_init(&cSlice_4759crkE, 1, -1);
  numBytes += cVar_init_f(&cVar_s9d2vEuL, 0.0f);
  numBytes += cSlice_init(&cSlice_5kjlk7o4, 1, -1);
  numBytes += cVar_init_f(&cVar_Y7yjjJkD, 0.0f);
  numBytes += cSlice_init(&cSlice_SxwGkO1u, 1, -1);
  numBytes += cVar_init_f(&cVar_pjiG5RTU, 0.313f);
  numBytes += cBinop_init(&cBinop_3zjwqAai, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Iv7AxItB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lpYrYbFQ, 0.0f);
  numBytes += cVar_init_f(&cVar_APWzh9t5, 1337.0f);
  numBytes += cVar_init_f(&cVar_1zBIllp5, 0.3f);
  numBytes += cBinop_init(&cBinop_Dg4kzjbQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GjJ0r60q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_87ywMf0h, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aT0JY6Ja, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8sCaTw68, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VG9VxOld, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uN6XpXPf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FQ902nOt, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_N9YpxU0c, 0.0f);
  numBytes += cVar_init_f(&cVar_djKBC6JK, 1337.0f);
  numBytes += cVar_init_f(&cVar_3P4SkBY5, 0.313f);
  numBytes += cBinop_init(&cBinop_Whuem0Ed, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KeBAMgUI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ciTtFNrB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jSa4hwgY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9iWOp4Fz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4D3Mwbl3, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_VcfwnpGc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lEa9gR5M, 0.0f);
  numBytes += cVar_init_f(&cVar_7Gvn4gtE, 1037.0f);
  numBytes += cVar_init_f(&cVar_moK361Rm, 0.4f);
  numBytes += cBinop_init(&cBinop_goznqwoo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_m47vjHWS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KLCPvqpG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UGxKJTYg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8Tpy8W2b, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WdwjZMSn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lPEpZ1nw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HVeF34tA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OF1jVdD3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nJwofBSB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_10wfDD44, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4GWYbkzU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iT6KFlKW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IspF2ZOk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W4p17SSJ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_T6Db65q5, 5705.6f);
  numBytes += cVar_init_f(&cVar_zmaNsDUf, 313.3f);
  numBytes += cBinop_init(&cBinop_dt57KuIY, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_1DsgQFbD, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_LSuKXpI1, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_58Og4Kz6_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JLs2VTPo_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_83kvNcw7_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4SNfmUE4_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BfX6RUF1_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pHbslfds_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sdz2Xz9S_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oAI3tNIw_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DjWuJ9v3_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QJ3ODicB_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UCXYKKRR_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RSsZJHsY_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NSUFcuUG_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qKzCZVY7_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KPYHoIA0_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_onJX4uWA_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rgcueciq_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IzwsZcT1_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_07wPQ7wL_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AgOfE25K_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UF8lRJIV_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vNWtHFb4_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mn493D4T_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YXIRdNOt_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CNW6yD5r_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tzgjcIRn_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dAAftDKN_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QWBym4OG_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2SG4zOYn_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_10mjWh6C_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CFeFj9i5_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1og6r1oc_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x3AnOB1s_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_02yOqzfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H5FUv6DF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_wmUCo5Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mtM7CiYC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_toDdlFNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EIqwyNFx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_gk0xLpib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K11AjaxO_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gtm6mZnY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YHidIriA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gTYTs4GS_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_Hqn6b5UQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aDtasS2x, 0, m, &cSlice_aDtasS2x_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iofZ4lfN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_aDtasS2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3DwQ5nNr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3DwQ5nNr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_iTuNFanq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3DwQ5nNr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_3DwQ5nNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Sdz2Xz9S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_BEVO6pxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lGIfmwVV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Fu7zfhYD, 0, m, &cIf_Fu7zfhYD_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Fu7zfhYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Hp064MSc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_BGQq0ax9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_EaTo44kS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_K3rfGzrZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_NkZ9DeRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ANYHxlaF, HV_BINOP_POW, 0, m, &cBinop_ANYHxlaF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ANYHxlaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WTMEwW08, 0, m, &cIf_WTMEwW08_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_920wIWXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_hJthWGDR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vwvCXF7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BGQq0ax9, 0, m, &cIf_BGQq0ax9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sEUgS6Bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ejLVB9KF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ejLVB9KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BGQq0ax9, 1, m, &cIf_BGQq0ax9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K3rfGzrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_920wIWXu_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EaTo44kS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WTMEwW08, 0, m, &cIf_WTMEwW08_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hJthWGDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ANYHxlaF, HV_BINOP_POW, 1, m, &cBinop_ANYHxlaF_sendMessage);
  cMsg_NkZ9DeRy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_WTMEwW08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_sKdQ3K0V, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_lGIfmwVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fu7zfhYD, 1, m, &cIf_Fu7zfhYD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hp064MSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3kuVtlCj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_3kuVtlCj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OtQdIPOk, HV_BINOP_EQ, 1, m, &cBinop_OtQdIPOk_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_KuqVzjEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jBtcYWmw, HV_BINOP_ADD, 0, m, &cBinop_jBtcYWmw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jBtcYWmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sEUgS6Bp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vwvCXF7l_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3kuVtlCj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WTMEwW08, 1, m, &cIf_WTMEwW08_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OtQdIPOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V6vMwxTf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_V6vMwxTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_sKdQ3K0V, m);
}

void Heavy_WSTD_EQ::cCast_3Qdy6fmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BEVO6pxK, 0, m, &cVar_BEVO6pxK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pqpbvynk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KuqVzjEx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_DGrDxDaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jBtcYWmw, HV_BINOP_ADD, 1, m, &cBinop_jBtcYWmw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3kuVtlCj, HV_BINOP_GREATER_THAN, 0, m, &cBinop_3kuVtlCj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OtQdIPOk, HV_BINOP_EQ, 0, m, &cBinop_OtQdIPOk_sendMessage);
}

void Heavy_WSTD_EQ::cVar_WcIdRQP3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iZot6OKB_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vbIIBqnL, 0, m, &cIf_vbIIBqnL_sendMessage);
}

void Heavy_WSTD_EQ::cIf_vbIIBqnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2rJRUAHV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_zGQ7BsKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_91UAejxB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3WIVvxId_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_a6VTX92I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g068qryB, HV_BINOP_POW, 0, m, &cBinop_g068qryB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g068qryB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rb0wENdK, 0, m, &cIf_Rb0wENdK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UrTLOKUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IoeESup8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KreI6omN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zGQ7BsKr, 0, m, &cIf_zGQ7BsKr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fr3i58n0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9DxD7WkT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9DxD7WkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zGQ7BsKr, 1, m, &cIf_zGQ7BsKr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3WIVvxId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_UrTLOKUJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_91UAejxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Rb0wENdK, 0, m, &cIf_Rb0wENdK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IoeESup8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g068qryB, HV_BINOP_POW, 1, m, &cBinop_g068qryB_sendMessage);
  cMsg_a6VTX92I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_Rb0wENdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wlXIdniC_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SmpqQ0en_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Ou8KCfB1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_iZot6OKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbIIBqnL, 1, m, &cIf_vbIIBqnL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2rJRUAHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ANLuXfLA, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ANLuXfLA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hfLTk31D, HV_BINOP_EQ, 1, m, &cBinop_hfLTk31D_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_HWGMq5T7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5EmnoKao, HV_BINOP_ADD, 0, m, &cBinop_5EmnoKao_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5EmnoKao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fr3i58n0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KreI6omN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ANLuXfLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rb0wENdK, 1, m, &cIf_Rb0wENdK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hfLTk31D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3FbZRx1j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_3FbZRx1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wlXIdniC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SmpqQ0en_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Ou8KCfB1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_j6VtDKRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HWGMq5T7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_wGQAcYPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5EmnoKao, HV_BINOP_ADD, 1, m, &cBinop_5EmnoKao_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ANLuXfLA, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ANLuXfLA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hfLTk31D, HV_BINOP_EQ, 0, m, &cBinop_hfLTk31D_sendMessage);
}

void Heavy_WSTD_EQ::cCast_H5oQn1ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WcIdRQP3, 0, m, &cVar_WcIdRQP3_sendMessage);
}

void Heavy_WSTD_EQ::cVar_wFJWBzAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TdRoSCVK_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_AlixYGfP, 0, m, &cIf_AlixYGfP_sendMessage);
}

void Heavy_WSTD_EQ::cIf_AlixYGfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jnsjpcSF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_YF2HbcMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_iJjf76LX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ZuCxUfYP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_GOJxASWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fSEhnV6, HV_BINOP_POW, 0, m, &cBinop_5fSEhnV6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5fSEhnV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uZGxHpg7, 0, m, &cIf_uZGxHpg7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g5EoozEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8th9jyyC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8piHw79w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YF2HbcMT, 0, m, &cIf_YF2HbcMT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vFxYwiMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OnafikVF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OnafikVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YF2HbcMT, 1, m, &cIf_YF2HbcMT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZuCxUfYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_g5EoozEJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_iJjf76LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uZGxHpg7, 0, m, &cIf_uZGxHpg7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8th9jyyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5fSEhnV6, HV_BINOP_POW, 1, m, &cBinop_5fSEhnV6_sendMessage);
  cMsg_GOJxASWQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_uZGxHpg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_BfTdSstz, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_TdRoSCVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AlixYGfP, 1, m, &cIf_AlixYGfP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jnsjpcSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UbfroCP4, HV_BINOP_GREATER_THAN, 1, m, &cBinop_UbfroCP4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EjlOIZ0Z, HV_BINOP_EQ, 1, m, &cBinop_EjlOIZ0Z_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_1o9aKCfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ru1dNYbC, HV_BINOP_ADD, 0, m, &cBinop_ru1dNYbC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ru1dNYbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vFxYwiMI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8piHw79w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UbfroCP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uZGxHpg7, 1, m, &cIf_uZGxHpg7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EjlOIZ0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gRmRtMrl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gRmRtMrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BfTdSstz, m);
}

void Heavy_WSTD_EQ::cCast_vDaXszPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wFJWBzAw, 0, m, &cVar_wFJWBzAw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pv9lL3LF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1o9aKCfO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_r9oK3cqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ru1dNYbC, HV_BINOP_ADD, 1, m, &cBinop_ru1dNYbC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UbfroCP4, HV_BINOP_GREATER_THAN, 0, m, &cBinop_UbfroCP4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EjlOIZ0Z, HV_BINOP_EQ, 0, m, &cBinop_EjlOIZ0Z_sendMessage);
}

void Heavy_WSTD_EQ::cIf_XE1ePSCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_IYWmfA2F, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_sGVzROQ3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yR2NnsAx, 0, m, &cSlice_yR2NnsAx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VHxPMqwr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_yR2NnsAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WGuSx7ym_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WGuSx7ym_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_4PVS3BTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WGuSx7ym_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_WGuSx7ym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BfX6RUF1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_VHxPMqwr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3ZfvpVkV, 0, m, &cSlice_3ZfvpVkV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Hqn6b5UQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_3ZfvpVkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HmccUU2s_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HmccUU2s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_36QsZEDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HmccUU2s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_HmccUU2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DjWuJ9v3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_iofZ4lfN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7B1n4s5Q, 0, m, &cSlice_7B1n4s5Q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XtPvNuO4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_7B1n4s5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CecrlNsN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CecrlNsN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_cQPDVtJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CecrlNsN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_CecrlNsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pHbslfds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_XtPvNuO4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sDf8K7nR, 0, m, &cSlice_sDf8K7nR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_sDf8K7nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_39uHujma_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_39uHujma_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_fLI5O37S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_39uHujma_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_39uHujma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oAI3tNIw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_x1MjzLh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bgQWnU7N, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IXH89bAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HCWUa98w, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mJudu3Rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_l0MBLnDE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AQeeXVs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lrNSe0OV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_PIZ0rDtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AWvzdjR1, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_U3jWoSEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TL52awyP_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_TL52awyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yRQdba44, HV_BINOP_DIVIDE, 1, m, &cBinop_yRQdba44_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZTyP9Xwm_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Q790WmDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_vvbmrzf5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PMiyRORP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Q790WmDy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vvbmrzf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yRQdba44, HV_BINOP_DIVIDE, 0, m, &cBinop_yRQdba44_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZTyP9Xwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PMiyRORP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yRQdba44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmBvsg8F, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZmBvsg8F_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZmBvsg8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PYykHCpg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LvOB0Je9_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_hlPS0z69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UGHerblH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_9Az0UnRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_flhfgjHf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UO0rN7VF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_leFBKEFc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_leFBKEFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZmBvsg8F, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZmBvsg8F_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ns8a7uGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1tOMDqGn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1tOMDqGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZA2hg7PW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Zbl4GM27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tv6lHtJj, 1, m, &cVar_Tv6lHtJj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Tv6lHtJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z61eJBWN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oeRTQSQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lsyLn6ph, HV_BINOP_MULTIPLY, 1, m, &cBinop_lsyLn6ph_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ofUfiopN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oeRTQSQS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WgMNMRyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RTd9VokE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RTd9VokE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4VpGgw6d, HV_BINOP_MULTIPLY, 1, m, &cBinop_4VpGgw6d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jPyTQ1En_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_woKhAn7E, HV_BINOP_MULTIPLY, 1, m, &cBinop_woKhAn7E_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wULIZXjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jPyTQ1En_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sPsLlFgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_piw2UGzD, HV_BINOP_MULTIPLY, 1, m, &cBinop_piw2UGzD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_knsK2bzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YWPPXWpd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YWPPXWpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9jKwLeQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_l9jKwLeQ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_C9xaVcAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bpxfQEKi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UO0rN7VF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SBFCuFwi_sendMessage);
}

void Heavy_WSTD_EQ::cVar_uU3X9ApG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Ns8a7uGi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LvOB0Je9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9Az0UnRs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PYykHCpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_hlPS0z69_sendMessage);
}

void Heavy_WSTD_EQ::cSend_UGHerblH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RSsZJHsY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_flhfgjHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UCXYKKRR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_cHjCJYXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QJ3ODicB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ZA2hg7PW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mUG5Sb7I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mUG5Sb7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZqu7wII, HV_BINOP_MULTIPLY, 1, m, &cBinop_UZqu7wII_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UZqu7wII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jGmkDZX4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jGmkDZX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cHjCJYXS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Z61eJBWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WXjprgUu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WXjprgUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KDQG3MAw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_029iLOlT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mwhQ6PpE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m4azxfwf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qek9DUzd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nrjpLMv6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lsyLn6ph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x1MjzLh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4VpGgw6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IXH89bAK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_woKhAn7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mJudu3Rf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_piw2UGzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AQeeXVs9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_l9jKwLeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PIZ0rDtV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_mbY4aHJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C9xaVcAd, 0, m, &cVar_C9xaVcAd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_i14YCv8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uU3X9ApG, 1, m, &cVar_uU3X9ApG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KDQG3MAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_nrjpLMv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lsyLn6ph, HV_BINOP_MULTIPLY, 0, m, &cBinop_lsyLn6ph_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mwhQ6PpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_piw2UGzD, HV_BINOP_MULTIPLY, 0, m, &cBinop_piw2UGzD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qek9DUzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4VpGgw6d, HV_BINOP_MULTIPLY, 0, m, &cBinop_4VpGgw6d_sendMessage);
}

void Heavy_WSTD_EQ::cCast_029iLOlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9jKwLeQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_l9jKwLeQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_m4azxfwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_woKhAn7E, HV_BINOP_MULTIPLY, 0, m, &cBinop_woKhAn7E_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SBFCuFwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tv6lHtJj, 0, m, &cVar_Tv6lHtJj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bpxfQEKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uU3X9ApG, 0, m, &cVar_uU3X9ApG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_30zXKLMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ns43tG3A, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_sj2nDP8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u8c9p1Ok, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bnkuYOWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lCedbyet, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BuLH5I54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vbekwRdh, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pO4y0kL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iHmpeNoY_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_iHmpeNoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vm9a940j, HV_BINOP_DIVIDE, 1, m, &cBinop_vm9a940j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dSaEuxRp_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_OEH7KNt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_DiLs2AHt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WyeWlkoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_OEH7KNt1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DiLs2AHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vm9a940j, HV_BINOP_DIVIDE, 0, m, &cBinop_vm9a940j_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dSaEuxRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WyeWlkoJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vm9a940j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8lTm10O4, HV_BINOP_MULTIPLY, 1, m, &cBinop_8lTm10O4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8lTm10O4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_crlgGohU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8XZtanVl_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_vKD05RPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RBuS6d0C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_KtMXdYx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JsCrNgyC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_C8xbtcPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_y8R4RGmX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_y8R4RGmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8lTm10O4, HV_BINOP_MULTIPLY, 0, m, &cBinop_8lTm10O4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AgA8bEvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_PtQKQv7E_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PtQKQv7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BkMK5Mdh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_o0QRHLgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mdtk8ozj, HV_BINOP_MULTIPLY, 1, m, &cBinop_mdtk8ozj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8UoX2WIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9rqvbLZj, 1, m, &cVar_9rqvbLZj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rUtFhAQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R6W87BP5, HV_BINOP_MULTIPLY, 1, m, &cBinop_R6W87BP5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6nNla3C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_D3kwRozq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D3kwRozq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rxj0OqEH, HV_BINOP_MULTIPLY, 1, m, &cBinop_Rxj0OqEH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_9rqvbLZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_loHeiGnZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_JzcNsurN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eGS1WuDH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_C8xbtcPV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qEJ5rGHd_sendMessage);
}

void Heavy_WSTD_EQ::cVar_E7w2xrx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_AgA8bEvx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_crlgGohU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_vKD05RPx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8XZtanVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_KtMXdYx1_sendMessage);
}

void Heavy_WSTD_EQ::cSend_RBuS6d0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KPYHoIA0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JsCrNgyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qKzCZVY7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_t1tzzApu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NSUFcuUG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_BkMK5Mdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0yAVWn65_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0yAVWn65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmVRfIU2, HV_BINOP_MULTIPLY, 1, m, &cBinop_YmVRfIU2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YmVRfIU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RaCTPgUR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RaCTPgUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t1tzzApu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_loHeiGnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MO88P6tt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MO88P6tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1XUMJqf4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eNLl2jbQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8u2YP4IC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l5w3LPjE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_N8jKWHDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_30zXKLMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mdtk8ozj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sj2nDP8R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_R6W87BP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bnkuYOWU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Rxj0OqEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BuLH5I54_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_GD2pieez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JzcNsurN, 0, m, &cVar_JzcNsurN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_r6M9rX3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E7w2xrx9, 1, m, &cVar_E7w2xrx9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eGS1WuDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E7w2xrx9, 0, m, &cVar_E7w2xrx9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qEJ5rGHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9rqvbLZj, 0, m, &cVar_9rqvbLZj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1XUMJqf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rxj0OqEH, HV_BINOP_MULTIPLY, 0, m, &cBinop_Rxj0OqEH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_l5w3LPjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N8jKWHDz, HV_BINOP_MULTIPLY, 0, m, &cBinop_N8jKWHDz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eNLl2jbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R6W87BP5, HV_BINOP_MULTIPLY, 0, m, &cBinop_R6W87BP5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8u2YP4IC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mdtk8ozj, HV_BINOP_MULTIPLY, 0, m, &cBinop_mdtk8ozj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5ItndEyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YxPaf8zY, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Vjvu88QG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VJu9PwHw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ypj81eQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8CKgqe7i, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_5KeXSXVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9jFPIohT, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jay0jkmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eCJuFOfQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JPcfbZIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_agp6q5Kz_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_agp6q5Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_txguN54Z, HV_BINOP_DIVIDE, 1, m, &cBinop_txguN54Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CxnVZy9t_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ylvm1fNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Q64bnUv0_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3tx8unAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ylvm1fNr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q64bnUv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_txguN54Z, HV_BINOP_DIVIDE, 0, m, &cBinop_txguN54Z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CxnVZy9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3tx8unAZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_txguN54Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DiBSwOzj, HV_BINOP_MULTIPLY, 1, m, &cBinop_DiBSwOzj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DiBSwOzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WYQlLuYV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E6RImBtO_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_a8lYA8q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xBOm4oIf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_0i4Rmrtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mJH5EMZT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_kzZYXbLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_JO2Ju7br_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JO2Ju7br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DiBSwOzj, HV_BINOP_MULTIPLY, 0, m, &cBinop_DiBSwOzj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_znEYnf2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_JpLzFobA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JpLzFobA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6DRDYdzZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Fzng4cZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7RiDy1qB, HV_BINOP_MULTIPLY, 1, m, &cBinop_7RiDy1qB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GlUJ7M7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iCaNVtJH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iCaNVtJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Fzng4cZA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ifmmi35o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2yBUsvrN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2yBUsvrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WWscL0Ip, HV_BINOP_MULTIPLY, 1, m, &cBinop_WWscL0Ip_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fya83aMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_equbDlXO, HV_BINOP_MULTIPLY, 1, m, &cBinop_equbDlXO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_dx6F1q49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ReNDCDxN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ReNDCDxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Fya83aMo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KXXLVJSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7AbWB6rR, 1, m, &cVar_7AbWB6rR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_airvZjcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bSRXDdBT, HV_BINOP_MULTIPLY, 1, m, &cBinop_bSRXDdBT_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wwsqxTU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_foSfZXwY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_foSfZXwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B0ZjljPU, HV_BINOP_MULTIPLY, 1, m, &cBinop_B0ZjljPU_sendMessage);
}

void Heavy_WSTD_EQ::cVar_7AbWB6rR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_R0MwD3vm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_0GYPE71e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uhQDBNKo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_kzZYXbLl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_srA7msMe_sendMessage);
}

void Heavy_WSTD_EQ::cVar_CKrIIoSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_znEYnf2Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WYQlLuYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_a8lYA8q4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_E6RImBtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0i4Rmrtk_sendMessage);
}

void Heavy_WSTD_EQ::cSend_xBOm4oIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IzwsZcT1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_mJH5EMZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rgcueciq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_b0gXFTns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_onJX4uWA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6DRDYdzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Bb7sQmon_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Bb7sQmon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CCV85RQ4, HV_BINOP_MULTIPLY, 1, m, &cBinop_CCV85RQ4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CCV85RQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6eBex9he_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6eBex9he_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b0gXFTns_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_R0MwD3vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hrI3BGXp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hrI3BGXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TsQRAg3L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_asZskuSu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fx7efuAw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xb5HvaSs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q8yn2gVs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oty3M6DA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7RiDy1qB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5ItndEyT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WWscL0Ip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vjvu88QG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_equbDlXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ypj81eQq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bSRXDdBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5KeXSXVo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_B0ZjljPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jay0jkmK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_ll36eLop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CKrIIoSf, 1, m, &cVar_CKrIIoSf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4oZo70op_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0GYPE71e, 0, m, &cVar_0GYPE71e_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Fx7efuAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bSRXDdBT, HV_BINOP_MULTIPLY, 0, m, &cBinop_bSRXDdBT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Xb5HvaSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_equbDlXO, HV_BINOP_MULTIPLY, 0, m, &cBinop_equbDlXO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Oty3M6DA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7RiDy1qB, HV_BINOP_MULTIPLY, 0, m, &cBinop_7RiDy1qB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Q8yn2gVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WWscL0Ip, HV_BINOP_MULTIPLY, 0, m, &cBinop_WWscL0Ip_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TsQRAg3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_asZskuSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B0ZjljPU, HV_BINOP_MULTIPLY, 0, m, &cBinop_B0ZjljPU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_srA7msMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7AbWB6rR, 0, m, &cVar_7AbWB6rR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uhQDBNKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CKrIIoSf, 0, m, &cVar_CKrIIoSf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wlXIdniC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XE1ePSCd, 1, m, &cIf_XE1ePSCd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_gemrg2wO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_IYWmfA2F, m);
}

void Heavy_WSTD_EQ::cBinop_SmpqQ0en_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gemrg2wO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Ou8KCfB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XE1ePSCd, 0, m, &cIf_XE1ePSCd_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_DhylDHET_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZXkAK71i, 0, m, &cSlice_ZXkAK71i_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mfrD6RCA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_ZXkAK71i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qtPe0qo6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qtPe0qo6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_5MKM0a5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qtPe0qo6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_qtPe0qo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UF8lRJIV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_comcRrAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rg5q3Ah4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vmM2heQ8, 0, m, &cIf_vmM2heQ8_sendMessage);
}

void Heavy_WSTD_EQ::cIf_vmM2heQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7X8b3aYY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_pfkDyPE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jeyMmwSl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_goIKTT4U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_cMtm8Hzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IRJ4E0rN, HV_BINOP_POW, 0, m, &cBinop_IRJ4E0rN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IRJ4E0rN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aWoLdBzS, 0, m, &cIf_aWoLdBzS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YhKLVnqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_AX4KfXDb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9dYfkBl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JmpxYC5x_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tF6s5hUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pfkDyPE6, 0, m, &cIf_pfkDyPE6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JmpxYC5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pfkDyPE6, 1, m, &cIf_pfkDyPE6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_goIKTT4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_YhKLVnqg_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_jeyMmwSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aWoLdBzS, 0, m, &cIf_aWoLdBzS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AX4KfXDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IRJ4E0rN, HV_BINOP_POW, 1, m, &cBinop_IRJ4E0rN_sendMessage);
  cMsg_cMtm8Hzx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_aWoLdBzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_lPEpZ1nw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_rg5q3Ah4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vmM2heQ8, 1, m, &cIf_vmM2heQ8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7X8b3aYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QquBMlKy, HV_BINOP_GREATER_THAN, 1, m, &cBinop_QquBMlKy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HMSCp0Zj, HV_BINOP_EQ, 1, m, &cBinop_HMSCp0Zj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_elJB6Ko9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ia9niJB3, HV_BINOP_ADD, 0, m, &cBinop_ia9niJB3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ia9niJB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9dYfkBl3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tF6s5hUF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QquBMlKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aWoLdBzS, 1, m, &cIf_aWoLdBzS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HMSCp0Zj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XfbkHzCO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_XfbkHzCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lPEpZ1nw, m);
}

void Heavy_WSTD_EQ::cCast_p2s1frOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_comcRrAl, 0, m, &cVar_comcRrAl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sJ1t7MHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_elJB6Ko9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_fB1sfUBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ia9niJB3, HV_BINOP_ADD, 1, m, &cBinop_ia9niJB3_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QquBMlKy, HV_BINOP_GREATER_THAN, 0, m, &cBinop_QquBMlKy_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HMSCp0Zj, HV_BINOP_EQ, 0, m, &cBinop_HMSCp0Zj_sendMessage);
}

void Heavy_WSTD_EQ::cVar_avf0XxJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qknS8joS_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_n93tcvaC, 0, m, &cIf_n93tcvaC_sendMessage);
}

void Heavy_WSTD_EQ::cIf_n93tcvaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Oxk21nYu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_Ge0dFVsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zv4QAmpc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ZJz6hTrI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_sA52qDho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zzm2PRXm, HV_BINOP_POW, 0, m, &cBinop_zzm2PRXm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zzm2PRXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2BKnqPgY, 0, m, &cIf_2BKnqPgY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lIyxEKVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BJFQiZnD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6034uUDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5fC0KrN1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VpDvQpLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ge0dFVsP, 0, m, &cIf_Ge0dFVsP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5fC0KrN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ge0dFVsP, 1, m, &cIf_Ge0dFVsP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZJz6hTrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_lIyxEKVc_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zv4QAmpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_2BKnqPgY, 0, m, &cIf_2BKnqPgY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BJFQiZnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zzm2PRXm, HV_BINOP_POW, 1, m, &cBinop_zzm2PRXm_sendMessage);
  cMsg_sA52qDho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_2BKnqPgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6Cl6r5xk_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7FKoyRzD_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_hZP4T9bG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_qknS8joS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n93tcvaC, 1, m, &cIf_n93tcvaC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Oxk21nYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_egLrQLDO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_egLrQLDO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Z1tQrQK, HV_BINOP_EQ, 1, m, &cBinop_7Z1tQrQK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GUNkatqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AUkfpzY8, HV_BINOP_ADD, 0, m, &cBinop_AUkfpzY8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AUkfpzY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6034uUDA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VpDvQpLO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_egLrQLDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2BKnqPgY, 1, m, &cIf_2BKnqPgY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7Z1tQrQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QyalaIuR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_QyalaIuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6Cl6r5xk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7FKoyRzD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_hZP4T9bG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EkypPMIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AUkfpzY8, HV_BINOP_ADD, 1, m, &cBinop_AUkfpzY8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_egLrQLDO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_egLrQLDO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Z1tQrQK, HV_BINOP_EQ, 0, m, &cBinop_7Z1tQrQK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CquFMYsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GUNkatqZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_i0btevds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_avf0XxJ2, 0, m, &cVar_avf0XxJ2_sendMessage);
}

void Heavy_WSTD_EQ::cVar_hekzcKjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RlSG1E75_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MsOeSNqr, 0, m, &cIf_MsOeSNqr_sendMessage);
}

void Heavy_WSTD_EQ::cIf_MsOeSNqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SbiQsRXN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_3tb23vXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RGFfgNFX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_dpIA2ZJM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_8h9GfvJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_n6LSvECA, HV_BINOP_POW, 0, m, &cBinop_n6LSvECA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_n6LSvECA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_skmGSQru, 0, m, &cIf_skmGSQru_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hZY4Ta09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_WaWyiGlE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_plnHedhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3tb23vXG, 0, m, &cIf_3tb23vXG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7MCvkHxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1oXe4AsE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1oXe4AsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3tb23vXG, 1, m, &cIf_3tb23vXG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dpIA2ZJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hZY4Ta09_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_RGFfgNFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_skmGSQru, 0, m, &cIf_skmGSQru_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WaWyiGlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n6LSvECA, HV_BINOP_POW, 1, m, &cBinop_n6LSvECA_sendMessage);
  cMsg_8h9GfvJ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_skmGSQru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_OF1jVdD3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_RlSG1E75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MsOeSNqr, 1, m, &cIf_MsOeSNqr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SbiQsRXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R9xz2dMs, HV_BINOP_GREATER_THAN, 1, m, &cBinop_R9xz2dMs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LMHAuT93, HV_BINOP_EQ, 1, m, &cBinop_LMHAuT93_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_N22cNWRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_F01UgdMa, HV_BINOP_ADD, 0, m, &cBinop_F01UgdMa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F01UgdMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7MCvkHxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_plnHedhZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R9xz2dMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_skmGSQru, 1, m, &cIf_skmGSQru_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LMHAuT93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F7wQnwMu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_F7wQnwMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OF1jVdD3, m);
}

void Heavy_WSTD_EQ::cCast_u5PuxIRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hekzcKjx, 0, m, &cVar_hekzcKjx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7NqhP8in_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F01UgdMa, HV_BINOP_ADD, 1, m, &cBinop_F01UgdMa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_R9xz2dMs, HV_BINOP_GREATER_THAN, 0, m, &cBinop_R9xz2dMs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LMHAuT93, HV_BINOP_EQ, 0, m, &cBinop_LMHAuT93_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MoV0uXKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N22cNWRw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_zGijTCCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_HVeF34tA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_L1ZuQQmU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h9IYuzk1, 0, m, &cSlice_h9IYuzk1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dZF9FcxI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_h9IYuzk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7up04AB1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7up04AB1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_AheKeFYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7up04AB1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_7up04AB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_07wPQ7wL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_dZF9FcxI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4759crkE, 0, m, &cSlice_4759crkE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DhylDHET_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_4759crkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_78ifDoDM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_78ifDoDM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_s9d2vEuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_78ifDoDM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_78ifDoDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mn493D4T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_mfrD6RCA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5kjlk7o4, 0, m, &cSlice_5kjlk7o4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zUnJSkNS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_5kjlk7o4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Po4DXgax_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Po4DXgax_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Y7yjjJkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Po4DXgax_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Po4DXgax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AgOfE25K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_zUnJSkNS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SxwGkO1u, 0, m, &cSlice_SxwGkO1u_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_SxwGkO1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PLgyY2Aq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PLgyY2Aq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_pjiG5RTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PLgyY2Aq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_PLgyY2Aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vNWtHFb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_xSifbAxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xxhJ8OVA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LgZsfDmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RPwjOfxb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Eg01vSzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tVQPJplh, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9JDHiXU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_og5utLJ3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_XwRYyjJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bIQsSsRK, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_cwgq3Sqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3VATH7za_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_3VATH7za_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3zjwqAai, HV_BINOP_DIVIDE, 1, m, &cBinop_3zjwqAai_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2q0na0q4_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_YZG2thHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_I0SNdJq8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_RrB4OIO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_YZG2thHY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_I0SNdJq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3zjwqAai, HV_BINOP_DIVIDE, 0, m, &cBinop_3zjwqAai_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2q0na0q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RrB4OIO5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3zjwqAai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iv7AxItB, HV_BINOP_MULTIPLY, 1, m, &cBinop_Iv7AxItB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Iv7AxItB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LU7VC8nU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DhaP7mS5_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Lq1RGwey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fpwtGzrD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_rouQBedI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PScbg5LC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_dZzIMWqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_k8ZvXwhn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k8ZvXwhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iv7AxItB, HV_BINOP_MULTIPLY, 0, m, &cBinop_Iv7AxItB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wZNlToA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_gBrptIZH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gBrptIZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lF7oNC5U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AW1GqSeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lpYrYbFQ, 1, m, &cVar_lpYrYbFQ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lpYrYbFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rj1xdA0h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_heRbGOqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GjJ0r60q, HV_BINOP_MULTIPLY, 1, m, &cBinop_GjJ0r60q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nYBJv0Ev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_heRbGOqZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xj7hJBWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CnYCUFR1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CnYCUFR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_87ywMf0h, HV_BINOP_MULTIPLY, 1, m, &cBinop_87ywMf0h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PeLfCAQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aT0JY6Ja, HV_BINOP_MULTIPLY, 1, m, &cBinop_aT0JY6Ja_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BFU3u1UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PeLfCAQa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sePc7Jxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sCaTw68, HV_BINOP_MULTIPLY, 1, m, &cBinop_8sCaTw68_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TQwU5ChU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LPEztlW7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LPEztlW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VG9VxOld, HV_BINOP_MULTIPLY, 1, m, &cBinop_VG9VxOld_sendMessage);
}

void Heavy_WSTD_EQ::cVar_APWzh9t5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j6w1nTa8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_dZzIMWqj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yl9TemmA_sendMessage);
}

void Heavy_WSTD_EQ::cVar_1zBIllp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wZNlToA0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LU7VC8nU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Lq1RGwey_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DhaP7mS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_rouQBedI_sendMessage);
}

void Heavy_WSTD_EQ::cSend_fpwtGzrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tzgjcIRn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_PScbg5LC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CNW6yD5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_oaNu8jfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YXIRdNOt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_lF7oNC5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HHQacoKx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HHQacoKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dg4kzjbQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Dg4kzjbQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Dg4kzjbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IFX1tqJX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IFX1tqJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oaNu8jfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_rj1xdA0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3269fL5M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3269fL5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T6JvZQeA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qYKqWM29_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sQG1mT7A_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lsQOppJg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5HsD8gKc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sw9Y2rmX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GjJ0r60q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xSifbAxY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_87ywMf0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LgZsfDmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_aT0JY6Ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Eg01vSzp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8sCaTw68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9JDHiXU0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VG9VxOld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XwRYyjJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_0ro252ND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_APWzh9t5, 0, m, &cVar_APWzh9t5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ql8YRpWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1zBIllp5, 1, m, &cVar_1zBIllp5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sQG1mT7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8sCaTw68, HV_BINOP_MULTIPLY, 0, m, &cBinop_8sCaTw68_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5HsD8gKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_87ywMf0h, HV_BINOP_MULTIPLY, 0, m, &cBinop_87ywMf0h_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qYKqWM29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VG9VxOld, HV_BINOP_MULTIPLY, 0, m, &cBinop_VG9VxOld_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Sw9Y2rmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GjJ0r60q, HV_BINOP_MULTIPLY, 0, m, &cBinop_GjJ0r60q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lsQOppJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aT0JY6Ja, HV_BINOP_MULTIPLY, 0, m, &cBinop_aT0JY6Ja_sendMessage);
}

void Heavy_WSTD_EQ::cCast_T6JvZQeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_yl9TemmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lpYrYbFQ, 0, m, &cVar_lpYrYbFQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_j6w1nTa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1zBIllp5, 0, m, &cVar_1zBIllp5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_eDu2MLJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6LoJHWS1, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_j4RKFzhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tnGau76Y, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_lh5xm1ph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fWP3lcY4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ml1bZf75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FewIlr4C, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_xeMz4pTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KHxFjEs5_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_KHxFjEs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uN6XpXPf, HV_BINOP_DIVIDE, 1, m, &cBinop_uN6XpXPf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yKhxArxX_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_LhpxI8ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_cvELjW5M_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_sBNC8hHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_LhpxI8ep_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cvELjW5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uN6XpXPf, HV_BINOP_DIVIDE, 0, m, &cBinop_uN6XpXPf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yKhxArxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sBNC8hHH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uN6XpXPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQ902nOt, HV_BINOP_MULTIPLY, 1, m, &cBinop_FQ902nOt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FQ902nOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RfTOPj0C_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fAMaxuXV_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ugjFLexI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BjswQNZ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_e9PD7827_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_spGR8xnW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vo7Rc5VV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_mtvPk7uR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mtvPk7uR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQ902nOt, HV_BINOP_MULTIPLY, 0, m, &cBinop_FQ902nOt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mrIh1TF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_vMdmVZW1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vMdmVZW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xYXqADUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5XDVVVDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ciTtFNrB, HV_BINOP_MULTIPLY, 1, m, &cBinop_ciTtFNrB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mL6Zf8qB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N9YpxU0c, 1, m, &cVar_N9YpxU0c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OAjhIxW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jSa4hwgY, HV_BINOP_MULTIPLY, 1, m, &cBinop_jSa4hwgY_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_HyI8K1CZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oDfYM81Y_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oDfYM81Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9iWOp4Fz, HV_BINOP_MULTIPLY, 1, m, &cBinop_9iWOp4Fz_sendMessage);
}

void Heavy_WSTD_EQ::cVar_N9YpxU0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g2SiRrCU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_djKBC6JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WfHbWh1J_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_vo7Rc5VV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XZOyPnMU_sendMessage);
}

void Heavy_WSTD_EQ::cVar_3P4SkBY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mrIh1TF5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fAMaxuXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_e9PD7827_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RfTOPj0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ugjFLexI_sendMessage);
}

void Heavy_WSTD_EQ::cSend_BjswQNZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2SG4zOYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_spGR8xnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QWBym4OG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_eHCWdZbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dAAftDKN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_xYXqADUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sq8wA51T_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sq8wA51T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Whuem0Ed, HV_BINOP_MULTIPLY, 1, m, &cBinop_Whuem0Ed_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Whuem0Ed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SyvuRd7L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SyvuRd7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eHCWdZbo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_g2SiRrCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OG0arSLq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OG0arSLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PvMr3x8J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kkOfwff1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YOYT3PIX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hLH46eJR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KeBAMgUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eDu2MLJY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ciTtFNrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j4RKFzhM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jSa4hwgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lh5xm1ph_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9iWOp4Fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ml1bZf75_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_jIdnnhtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_djKBC6JK, 0, m, &cVar_djKBC6JK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ht6MQQ5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3P4SkBY5, 1, m, &cVar_3P4SkBY5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WfHbWh1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3P4SkBY5, 0, m, &cVar_3P4SkBY5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XZOyPnMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N9YpxU0c, 0, m, &cVar_N9YpxU0c_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PvMr3x8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9iWOp4Fz, HV_BINOP_MULTIPLY, 0, m, &cBinop_9iWOp4Fz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YOYT3PIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ciTtFNrB, HV_BINOP_MULTIPLY, 0, m, &cBinop_ciTtFNrB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kkOfwff1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jSa4hwgY, HV_BINOP_MULTIPLY, 0, m, &cBinop_jSa4hwgY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hLH46eJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KeBAMgUI, HV_BINOP_MULTIPLY, 0, m, &cBinop_KeBAMgUI_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_4HL5yKhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gQb3FBJB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_12hnLdyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lIokGcfM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eWqd1nAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PUG2Vmnt, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_I7eRl4B9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B9hRspnQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_y8iQG4Re_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MiJ0wviz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_HIKJNP3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I3p9EB0P_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_I3p9EB0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4D3Mwbl3, HV_BINOP_DIVIDE, 1, m, &cBinop_4D3Mwbl3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FsDIBMzW_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_uPEDRmUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ZSa70OrG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_BH9ayprz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_uPEDRmUy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZSa70OrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4D3Mwbl3, HV_BINOP_DIVIDE, 0, m, &cBinop_4D3Mwbl3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FsDIBMzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BH9ayprz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4D3Mwbl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VcfwnpGc, HV_BINOP_MULTIPLY, 1, m, &cBinop_VcfwnpGc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VcfwnpGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ofTTzdLl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ozFqli2I_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_kmkEDO1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_htjAVaB5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_61hanb3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yjKuBbhL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ae2FmY5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xUKHXuvY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xUKHXuvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VcfwnpGc, HV_BINOP_MULTIPLY, 0, m, &cBinop_VcfwnpGc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Yhqoxek6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AxGe6ANX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AxGe6ANX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_baWdpGie_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3wsGY1ay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m47vjHWS, HV_BINOP_MULTIPLY, 1, m, &cBinop_m47vjHWS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_jDHrGKQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oKGzb0QI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oKGzb0QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3wsGY1ay_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7g63B0zg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IK4cqkFd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IK4cqkFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KLCPvqpG, HV_BINOP_MULTIPLY, 1, m, &cBinop_KLCPvqpG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KRfUd7s7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UGxKJTYg, HV_BINOP_MULTIPLY, 1, m, &cBinop_UGxKJTYg_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_yZeDFrDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nbh6accg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nbh6accg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KRfUd7s7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PYQgnU6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lEa9gR5M, 1, m, &cVar_lEa9gR5M_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VroHJn9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Tpy8W2b, HV_BINOP_MULTIPLY, 1, m, &cBinop_8Tpy8W2b_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_K0cMuyaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kHHKfZ8U_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kHHKfZ8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WdwjZMSn, HV_BINOP_MULTIPLY, 1, m, &cBinop_WdwjZMSn_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lEa9gR5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhDh9WaM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_7Gvn4gtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mBJ05FaO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ae2FmY5w_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A8UB2XmO_sendMessage);
}

void Heavy_WSTD_EQ::cVar_moK361Rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Yhqoxek6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ozFqli2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_61hanb3C_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ofTTzdLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kmkEDO1l_sendMessage);
}

void Heavy_WSTD_EQ::cSend_htjAVaB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1og6r1oc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_yjKuBbhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CFeFj9i5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_BizayESp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_10mjWh6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_baWdpGie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZXnBZ4m8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZXnBZ4m8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_goznqwoo, HV_BINOP_MULTIPLY, 1, m, &cBinop_goznqwoo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_goznqwoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ppXwroSp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ppXwroSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BizayESp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hhDh9WaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jbvsokzO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jbvsokzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QcLppjLR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hni4AJqW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L5ZjACJr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FCefK6Yw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yPcHyWXI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U3JBH6Xi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_m47vjHWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4HL5yKhn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KLCPvqpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_12hnLdyN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UGxKJTYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eWqd1nAN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8Tpy8W2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I7eRl4B9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WdwjZMSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y8iQG4Re_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_4Dmb6T3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_moK361Rm, 1, m, &cVar_moK361Rm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_W6Q4QMZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7Gvn4gtE, 0, m, &cVar_7Gvn4gtE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yPcHyWXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KLCPvqpG, HV_BINOP_MULTIPLY, 0, m, &cBinop_KLCPvqpG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QcLppjLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_U3JBH6Xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m47vjHWS, HV_BINOP_MULTIPLY, 0, m, &cBinop_m47vjHWS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_L5ZjACJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Tpy8W2b, HV_BINOP_MULTIPLY, 0, m, &cBinop_8Tpy8W2b_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hni4AJqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WdwjZMSn, HV_BINOP_MULTIPLY, 0, m, &cBinop_WdwjZMSn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FCefK6Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UGxKJTYg, HV_BINOP_MULTIPLY, 0, m, &cBinop_UGxKJTYg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_A8UB2XmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lEa9gR5M, 0, m, &cVar_lEa9gR5M_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mBJ05FaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_moK361Rm, 0, m, &cVar_moK361Rm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6Cl6r5xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zGijTCCs, 1, m, &cIf_zGijTCCs_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_A9nc2XzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HVeF34tA, m);
}

void Heavy_WSTD_EQ::cBinop_7FKoyRzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A9nc2XzR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hZP4T9bG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zGijTCCs, 0, m, &cIf_zGijTCCs_sendMessage);
}

void Heavy_WSTD_EQ::cVar_T6Db65q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1DsgQFbD, HV_BINOP_DIVIDE, 0, m, &cBinop_1DsgQFbD_sendMessage);
}

void Heavy_WSTD_EQ::cVar_zmaNsDUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dt57KuIY, HV_BINOP_DIVIDE, 1, m, &cBinop_dt57KuIY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1DsgQFbD, HV_BINOP_DIVIDE, 1, m, &cBinop_1DsgQFbD_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_BGlaUaNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LSuKXpI1, HV_BINOP_DIVIDE, 0, m, &cBinop_LSuKXpI1_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_RsNiEM7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LSuKXpI1, HV_BINOP_DIVIDE, 1, m, &cBinop_LSuKXpI1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YHidIriA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T6Db65q5, 0, m, &cVar_T6Db65q5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gtm6mZnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zmaNsDUf, 0, m, &cVar_zmaNsDUf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gTYTs4GS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dt57KuIY, HV_BINOP_DIVIDE, 0, m, &cBinop_dt57KuIY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dt57KuIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_BGlaUaNa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1DsgQFbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_RsNiEM7i_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LSuKXpI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_kP6AricI_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_twCapvQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_tULBQV4D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IXENdNXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_l84zJ6Rk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kP6AricI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IXENdNXy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_l84zJ6Rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_twCapvQW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tULBQV4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qx6Y3RnN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_H5FUv6DF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sGVzROQ3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_L1ZuQQmU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mtM7CiYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sGVzROQ3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_L1ZuQQmU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EIqwyNFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sGVzROQ3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_L1ZuQQmU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_K11AjaxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sGVzROQ3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_L1ZuQQmU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Qx6Y3RnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sGVzROQ3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_L1ZuQQmU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3Bc7kwpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_gk0xLpib, 0, m, &cVar_gk0xLpib_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fMWA4luM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_02yOqzfZ, 0, m, &cVar_02yOqzfZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wmUCo5Xz, 0, m, &cVar_wmUCo5Xz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_toDdlFNp, 0, m, &cVar_toDdlFNp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_58Og4Kz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_02yOqzfZ, 0, m, &cVar_02yOqzfZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_83kvNcw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wmUCo5Xz, 0, m, &cVar_wmUCo5Xz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_JLs2VTPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_toDdlFNp, 0, m, &cVar_toDdlFNp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Sdz2Xz9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JzcNsurN, 0, m, &cVar_JzcNsurN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_oAI3tNIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r6M9rX3i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GD2pieez_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_BfX6RUF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Qdy6fmy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DGrDxDaC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pqpbvynk_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pHbslfds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vDaXszPZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r9oK3cqC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pv9lL3LF_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_DjWuJ9v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H5oQn1ep_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wGQAcYPl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j6VtDKRG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_x3AnOB1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U3jWoSEL_sendMessage(_c, 0, m);
  cMsg_pO4y0kL2_sendMessage(_c, 0, m);
  cMsg_JPcfbZIK_sendMessage(_c, 0, m);
  cMsg_cwgq3Sqc_sendMessage(_c, 0, m);
  cMsg_xeMz4pTv_sendMessage(_c, 0, m);
  cMsg_HIKJNP3b_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_C9xaVcAd, 0, m, &cVar_C9xaVcAd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JzcNsurN, 0, m, &cVar_JzcNsurN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0GYPE71e, 0, m, &cVar_0GYPE71e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_APWzh9t5, 0, m, &cVar_APWzh9t5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_djKBC6JK, 0, m, &cVar_djKBC6JK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7Gvn4gtE, 0, m, &cVar_7Gvn4gtE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iTuNFanq, 0, m, &cVar_iTuNFanq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BEVO6pxK, 0, m, &cVar_BEVO6pxK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WcIdRQP3, 0, m, &cVar_WcIdRQP3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wFJWBzAw, 0, m, &cVar_wFJWBzAw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4PVS3BTw, 0, m, &cVar_4PVS3BTw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_36QsZEDv, 0, m, &cVar_36QsZEDv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cQPDVtJ0, 0, m, &cVar_cQPDVtJ0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fLI5O37S, 0, m, &cVar_fLI5O37S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5MKM0a5E, 0, m, &cVar_5MKM0a5E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_comcRrAl, 0, m, &cVar_comcRrAl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_avf0XxJ2, 0, m, &cVar_avf0XxJ2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hekzcKjx, 0, m, &cVar_hekzcKjx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AheKeFYL, 0, m, &cVar_AheKeFYL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_s9d2vEuL, 0, m, &cVar_s9d2vEuL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y7yjjJkD, 0, m, &cVar_Y7yjjJkD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pjiG5RTU, 0, m, &cVar_pjiG5RTU_sendMessage);
  cMsg_fMWA4luM_sendMessage(_c, 0, m);
  cMsg_3Bc7kwpR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_RSsZJHsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZqu7wII, HV_BINOP_MULTIPLY, 0, m, &cBinop_UZqu7wII_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UCXYKKRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ofUfiopN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WgMNMRyF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wULIZXjC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_sPsLlFgM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_QJ3ODicB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Zbl4GM27_sendMessage);
  cMsg_knsK2bzh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_KPYHoIA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YmVRfIU2, HV_BINOP_MULTIPLY, 0, m, &cBinop_YmVRfIU2_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qKzCZVY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_rUtFhAQd_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_NSUFcuUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N8jKWHDz, HV_BINOP_MULTIPLY, 1, m, &cBinop_N8jKWHDz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_o0QRHLgp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8UoX2WIv_sendMessage);
  cMsg_6nNla3C4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_IzwsZcT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CCV85RQ4, HV_BINOP_MULTIPLY, 0, m, &cBinop_CCV85RQ4_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rgcueciq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GlUJ7M7q_sendMessage(_c, 0, m);
  cMsg_ifmmi35o_sendMessage(_c, 0, m);
  cMsg_dx6F1q49_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_airvZjcm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_onJX4uWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KXXLVJSe_sendMessage);
  cMsg_wwsqxTU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_UF8lRJIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_djKBC6JK, 0, m, &cVar_djKBC6JK_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_vNWtHFb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ht6MQQ5i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jIdnnhtB_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_07wPQ7wL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p2s1frOW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fB1sfUBj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sJ1t7MHn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_AgOfE25K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u5PuxIRl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7NqhP8in_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MoV0uXKs_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Mn493D4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i0btevds_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EkypPMIM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CquFMYsV_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tzgjcIRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dg4kzjbQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dg4kzjbQ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CNW6yD5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nYBJv0Ev_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xj7hJBWj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BFU3u1UU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_sePc7Jxr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_YXIRdNOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AW1GqSeW_sendMessage);
  cMsg_TQwU5ChU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_2SG4zOYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Whuem0Ed, HV_BINOP_MULTIPLY, 0, m, &cBinop_Whuem0Ed_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_QWBym4OG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_OAjhIxW3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_dAAftDKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KeBAMgUI, HV_BINOP_MULTIPLY, 1, m, &cBinop_KeBAMgUI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5XDVVVDo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mL6Zf8qB_sendMessage);
  cMsg_HyI8K1CZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_1og6r1oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_goznqwoo, HV_BINOP_MULTIPLY, 0, m, &cBinop_goznqwoo_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CFeFj9i5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jDHrGKQl_sendMessage(_c, 0, m);
  cMsg_7g63B0zg_sendMessage(_c, 0, m);
  cMsg_yZeDFrDW_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VroHJn9Z_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_10mjWh6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PYQgnU6J_sendMessage);
  cMsg_K0cMuyaQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_4SNfmUE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gk0xLpib, 0, m, &cVar_gk0xLpib_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_nJwofBSB, VOf(Bf0));
    __hv_varread_f(&sVarf_10wfDD44, VOf(Bf1));
    __hv_varread_f(&sVarf_4GWYbkzU, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_iT6KFlKW, VOf(Bf0));
    __hv_varread_f(&sVarf_IspF2ZOk, VOf(Bf1));
    __hv_varread_f(&sVarf_W4p17SSJ, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_bgQWnU7N, VOf(Bf0));
    __hv_line_f(&sLine_HCWUa98w, VOf(Bf1));
    __hv_line_f(&sLine_l0MBLnDE, VOf(Bf4));
    __hv_line_f(&sLine_lrNSe0OV, VOf(Bf5));
    __hv_line_f(&sLine_AWvzdjR1, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_NMGwHMRJ, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_sKdQ3K0V, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ns43tG3A, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_u8c9p1Ok, VOf(Bf1));
    __hv_line_f(&sLine_lCedbyet, VOf(Bf0));
    __hv_line_f(&sLine_vbekwRdh, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_BLD12yEt, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_IYWmfA2F, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_YxPaf8zY, VOf(Bf7));
    __hv_line_f(&sLine_VJu9PwHw, VOf(Bf1));
    __hv_line_f(&sLine_8CKgqe7i, VOf(Bf4));
    __hv_line_f(&sLine_9jFPIohT, VOf(Bf6));
    __hv_line_f(&sLine_eCJuFOfQ, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_TZJj3E9k, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_BfTdSstz, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_nJwofBSB, VIf(Bf5));
    __hv_varwrite_f(&sVarf_10wfDD44, VIf(Bf0));
    __hv_varwrite_f(&sVarf_4GWYbkzU, VIf(Bf6));
    __hv_line_f(&sLine_xxhJ8OVA, VOf(Bf6));
    __hv_line_f(&sLine_RPwjOfxb, VOf(Bf0));
    __hv_line_f(&sLine_tVQPJplh, VOf(Bf5));
    __hv_line_f(&sLine_og5utLJ3, VOf(Bf8));
    __hv_line_f(&sLine_bIQsSsRK, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_0jwAvb7b, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_lPEpZ1nw, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_6LoJHWS1, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_tnGau76Y, VOf(Bf0));
    __hv_line_f(&sLine_fWP3lcY4, VOf(Bf6));
    __hv_line_f(&sLine_FewIlr4C, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_6qMngM2P, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_HVeF34tA, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_gQb3FBJB, VOf(Bf1));
    __hv_line_f(&sLine_lIokGcfM, VOf(Bf0));
    __hv_line_f(&sLine_PUG2Vmnt, VOf(Bf5));
    __hv_line_f(&sLine_B9hRspnQ, VOf(Bf4));
    __hv_line_f(&sLine_MiJ0wviz, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_Vnc04Drh, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_OF1jVdD3, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_iT6KFlKW, VIf(Bf8));
    __hv_varwrite_f(&sVarf_IspF2ZOk, VIf(Bf6));
    __hv_varwrite_f(&sVarf_W4p17SSJ, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
